# Changelog

## [0.1.1](https://github.com/RISE-Dependable-Transport-Systems/fragmenter/compare/v0.1.0...v0.1.1) (2026-02-17)


### Bug Fixes

* bootstap release-please again with user-facing commit ([4969a64](https://github.com/RISE-Dependable-Transport-Systems/fragmenter/commit/4969a64736c54876b5f88b8de8fc694fb7ae43f1))

## Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
